==> streamtuner-0.11.1.tar.gz: streamtuner-0.11.1/src/streamtuner/st-network-tab.h <==
/*
 * $Id: st-network-tab.h,v 1.7 2004/01/05 19:44:10 jylefort Exp $
 *
 * Copyright (c) 2002, 2003 Jean-Yves Lefort
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of Jean-Yves Lefort nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 * CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
 * TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef _ST_NETWORK_TAB_H
#define _ST_NETWORK_TAB_H

#include <gtk/gtk.h>
#include "st-preferences-tab.h"

#define ST_TYPE_NETWORK_TAB		(st_network_tab_get_type())
#define ST_NETWORK_TAB(obj)		(G_TYPE_CHECK_INSTANCE_CAST((obj), ST_TYPE_NETWORK_TAB, STNetworkTab))
#define ST_NETWORK_TAB_CLASS(klass)	(G_TYPE_CHECK_CLASS_CAST((klass), ST_TYPE_NETWORK_TAB, STNetworkTabClass))
#define ST_IS_NETWORK_TAB(obj)		(G_TYPE_CHECK_INSTANCE_TYPE((obj), ST_TYPE_NETWORK_TAB))
#define ST_IS_NETWORK_TAB_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE((klass), ST_TYPE_NETWORK_TAB))
#define ST_NETWORK_TAB_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS((obj), ST_TYPE_NETWORK_TAB, STNetworkTabClass))

typedef struct
{
  STPreferencesTab		tab;
  
  GtkWidget			*table;

  GtkWidget			*proxy_check;

  GtkWidget			*url_label;
  GtkWidget			*url_entry;

  GtkWidget			*auth_check;

  GtkWidget			*name_label;
  GtkWidget			*name_entry;

  GtkWidget			*password_label;
  GtkWidget			*password_entry;
} STNetworkTab;

typedef struct
{
  STPreferencesTabClass		parent_class;
} STNetworkTabClass;

GType		st_network_tab_get_type		(void);
GtkWidget	*st_network_tab_new		(void);

#endif /* _ST_NETWORK_TAB_H */

==> streamtuner_0.12.1.orig.tar.gz: streamtuner-0.12.1/src/streamtuner/st-network-tab.h <==
/*
 * $Id: st-network-tab.h,v 1.11 2004/03/15 19:43:15 jylefort Exp $
 *
 * Copyright (c) 2002, 2003, 2004 Jean-Yves Lefort
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. Neither the name of Jean-Yves Lefort nor the names of its contributors
 *    may be used to endorse or promote products derived from this software
 *    without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND
 * CONTRIBUTORS "AS IS" AND ANY EXPRESS OR IMPLIED WARRANTIES,
 * INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES OF
 * MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT OWNER OR CONTRIBUTORS
 * BE LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL,
 * EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED
 * TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY,
 * OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
 * OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE
 * POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef _ST_NETWORK_TAB_H
#define _ST_NETWORK_TAB_H

#include <gtk/gtk.h>
#include "st-preferences-tab.h"

#define ST_TYPE_NETWORK_TAB		(st_network_tab_get_type())
#define ST_NETWORK_TAB(obj)		(G_TYPE_CHECK_INSTANCE_CAST((obj), ST_TYPE_NETWORK_TAB, STNetworkTab))
#define ST_NETWORK_TAB_CLASS(klass)	(G_TYPE_CHECK_CLASS_CAST((klass), ST_TYPE_NETWORK_TAB, STNetworkTabClass))
#define ST_IS_NETWORK_TAB(obj)		(G_TYPE_CHECK_INSTANCE_TYPE((obj), ST_TYPE_NETWORK_TAB))
#define ST_IS_NETWORK_TAB_CLASS(klass)	(G_TYPE_CHECK_CLASS_TYPE((klass), ST_TYPE_NETWORK_TAB))
#define ST_NETWORK_TAB_GET_CLASS(obj)	(G_TYPE_INSTANCE_GET_CLASS((obj), ST_TYPE_NETWORK_TAB, STNetworkTabClass))

typedef struct _STNetworkTabPrivate STNetworkTabPrivate;

typedef struct
{
  STPreferencesTab		tab;
  
  STNetworkTabPrivate		*priv;
} STNetworkTab;

typedef struct
{
  STPreferencesTabClass		parent_class;
} STNetworkTabClass;

GType		st_network_tab_get_type		(void);
GtkWidget	*st_network_tab_new		(void);

#endif /* _ST_NETWORK_TAB_H */
